<?php
/* Copyright (C) 2012   Stephen Larroque <lrq3000@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *      \file       htdocs/customfields/class/actions_customfields.class.php
 *      \ingroup    customfields
 *      \brief      Hook file for CustomFields to manage printing and editing in module's forms and datasheets
 *		\version    $Id: actions_customfields.class.php, v1.2.0
 *		\author		Stephen Larroque
 */

/**
 *      \class      actions_customfields
 *      \brief      Hook file for CustomFields to manage printing and editing in module's forms and datasheets
 */
class ActionsCustomFields // extends CommonObject
{

    /** Generic printing hook for the CustomFields module: call it with the right $printtype and it will do the rest for you!
     *  @param      printtype       'create'|'edit'
     *  @param      parameters  meta datas of the hook (context, etc...)
     *  @param      object             the object you want to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     *  @param      action             current action (if set). Generally create or edit or null
     *  @return       void
     */
    function customfields_print_forms($printtype, $parameters, $object, $action = null) {
        global $conf, $user;
        // CustomFields : print fields at creation and edition (will prepare the data for the printing library in lib folder)
        if ($conf->global->MAIN_MODULE_CUSTOMFIELDS) { // if the customfields module is activated...
            if (!is_object($parameters)) $parameters = (object)$parameters; // fix for a bug of $parameters which is not always an object (sometimes it's an array)

            // Initializing variables
            $idvar = 'id'; // default value
            $rights = null; // default value
            if (!isset($action)) $action = GETPOST('action'); // Get action var if it was not set

            // Preparing the CustomFields print arguments
            if ($parameters->context == 'invoicecard' or $object->table_element == 'facture') { // for invoices
                $currentmodule = 'facture';
                $idvar = 'facid';
                $rights = '$user->rights->facture->creer';
            }
            elseif ($parameters->context == 'propalcard' or $object->table_element == 'propal') { // for propales
                $currentmodule = 'propal'; // EDIT ME: var to edit for each module
                $idvar = 'id'; // EDIT ME: the name of the POST or GET variable that contains the id of the object (look at the URL for something like module.php?modid=3&... when you edit a field)
                $rights = '$user->rights->propale->creer'; // EDIT ME: try first to put it null, then if it doesn't work try to find the right name (search in the same file for something like $user->rights->modname where modname is the string you must put in $rights).
            }
            elseif ($parameters->context == 'productcard' or $object->table_element == 'product') { // for products/services
                $currentmodule = 'product';
                $idvar = 'id';
                // We use different rights depending on the product type (product or service?)
                // we need to supply it in the $rights var because product module has not the same name in rights property
                if ($object->type == 0) {
                        $rights = '$user->rights->produit->creer';
                } elseif ($object->type == 1) {
                        $rights = '$user->rights->service->creer';
                }
            }
            else { // Generic Hook : else we try a generic approach, based on the $modulesarray (contexts, table_element, idvar, etc..)
                include(DOL_DOCUMENT_ROOT."/customfields/conf/conf_customfields.lib.php");
                include_once(DOL_DOCUMENT_ROOT."/customfields/conf/conf_customfields_func.lib.php");


                // -- Search if a similar context can be found in $modulesarray (array of supported modules by CustomFields) - must be done first!
                // Contexts are stored as a string separated by ':', so we split it to an array
                $contexts = explode(':', $parameters->context);
                $found = false; // will be used to make sure that once we've found the module's parameters, we won't search anymore

                foreach ($contexts as $context) { // for each contexts
                    if (in_array($context, array_values_recursive('context', $modulesarray))) {
                        $tmpmod = array_extract_recursive(array('context'=>$context), $modulesarray); // Extract the subarray containing the found context
                        $currentmodule = $tmpmod[0]['table_element']; // Assign the module's name (table_element)

                        $found = true;
                        break;
                    }
                }
                // -- Search if a similar table_element (Dolibarr's module) can be found in $modulesarray - only if the module could not be found by context!
                if (!$found and in_array($object->table_element, array_values_recursive('table_element', $modulesarray))) {
                    $currentmodule = $object->table_element;
                    // set id variable if specified in $modulesarray (by default = 'id')
                    $tmpmod = array_extract_recursive(array('table_element'=>$object->table_element), $modulesarray); // Extract the subarray containing the found context
                    if (isset($tmpmod[0]['idvar'])) $idvar = $tmpmod[0]['idvar'];
                }

                // -- Set a few more parameters
                // set id variable if specified in $modulesarray (by default = 'id')
                if (isset($tmpmod[0]['idvar'])) $idvar = $tmpmod[0]['idvar'];
                // set rights  if specified
                if (isset($tmpmod[0]['rights'])) $rights = $tmpmod[0]['rights'];
            }

            include_once(DOL_DOCUMENT_ROOT.'/customfields/lib/customfields.lib.php');
            print '<br>';

            if ($printtype == 'create') {
                $action == 'edit' ?  $id = $object->id : $id = null; // If we are in a create form used to edit already instanciated fields, then we fetch the instanciated object by its id
                customfields_print_creation_form($currentmodule, $parameters, $action, $id);
            } else {
                customfields_print_main_form($currentmodule, $object, $parameters, $action, $user, $idvar, $rights);
            }
        }
    }

    /** formObjectOptions is a function that is included in the datasheet of all the objects Dolibarr can handle (invoices, propales, products, services, and more soon Ihope...)
     *   It is very useful if you want to include your own data in a datasheet.
     *
     */
    function formObjectOptions($parameters, $object, $action) {
        /* print_r($parameters);
            echo "action: ".$action;
            print_r($object); */
        print('CUSTOMFIELDS ACTIONS DETECTED'); //debugline

        if (!isset($object->element) or $action == 'create' or $action == 'add' or $action == 'edit') { // For the special case of edit (create form but used to edit parameters), this case is handled in the customfields lib and in the customfields_print_forms() function above (see $action == 'edit').
            $printtype = 'create';
        } else {
            $printtype = 'edit';
        }
        $this->customfields_print_forms($printtype, $parameters, $object, $action);
    }

    // Add customfields in forms that adds new lines (eg: products/services lines in invoices, etc..)
    /* Note: doesn't work with Dolibarr < v3.2.0
    function formAddObject($parameters, $object, $action) {
        print('CUSTOMFIELDS ACTIONS ADDLINE DETECTED'); //debugline
        //$this->formObjectOptions($parameters, $object, $action);
    }
    */

    /* Add customfields as options in forms that adds new lines for modules that supports it (eg: supplier's orders, etc.)
    function formCreateProductSupplierOptions($parameters, $object, $action) {
        print('CUSTOMFIELDS ACTIONS ADDLINE PRODUCT DETECTED'); //debugline
        //$this->formObjectOptions($parameters, $object, $action);
    }
    */

}
