<?php
/* Copyright (C) 2012   Stephen Larroque <lrq3000@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	\file       htdocs/customfields/conf/conf_customfields.lib.php
 *	\ingroup    others
 *	\brief          Contains all the configurable variables to expand the functionnalities of CustomFields
 *	\version    $Id: customfields.php, v1.3.0
 */

// Loading the translation class if it's not yet loaded (or with another name) - DO NOT EDIT!
if (! is_object($langs))
{
    include_once(DOL_DOCUMENT_ROOT."/core/class/translate.class.php");
    $langs=new Translate(DOL_DOCUMENT_ROOT."/customfields/langs/",$conf);
}

$langs->load('customfields@customfields'); // customfields standard language support
$langs->load('customfields-user@customfields'); // customfields language support for user's values (like enum, fields names, etc..)

// **** EXPANSIONVARIABLES ****
// Here you can edit the values to expand the functionnalities of CustomFields (it will try to automatically manage the changes, if not you can add special cases by yourselves, please refer to the Readme-CF.txt)

$fields_prefix = 'cf_'; // prefix that will be prepended to the variable name of a field for accessing the field's values

// $modulesarray contains the modules support and their associated contexts : contexts, table_element (= main module's name, the name of the module in the database like llx_product, product is the table_element), idvar
// Note: table_element is the main identifier for a module (this is the basis of CustomFields and of most of Dolibarr's code), while context is only used for hooks (actions_customfields.class.php).
$modulesarray = array( array('context'=>'invoicecard', 'table_element'=>'facture'), // Client Invoice
                                            array('context'=>'propalcard', 'table_element'=>'propal'), // Client Propale
                                            array('context'=>'productcard', 'table_element'=>'product'), // Products and Services

                                            array('context'=>'ordercard', 'table_element'=>'commande'), // Clients orders
                                            array('context'=>'thirdpartycard', 'table_element'=>'societe', 'idvar'=>'socid'), // Tiers / Society
                                            array('context'=>'contactcard', 'table_element'=>'socpeople', 'rights'=>array('$user->rights->societe->contact->creer')), // Contact

                                            array('context'=>'ordersuppliercard', 'table_element'=>'commande_fournisseur', 'rights'=>array('$user->rights->fournisseur->commande->creer')), // Supplier orders
                                            array('context'=>'invoicesuppliercard', 'table_element'=>'facture_fourn', 'rights'=>array('$user->rights->fournisseur->facture->creer')), // Supplier invoices
                                            array('context'=>'membercard', 'table_element'=>'adherent', 'idvar'=>'rowid', 'rights'=>array('$user->rights->adherent->creer')), // Members / Adherents
                                            array('context'=>'actioncard', 'table_element'=>'actioncomm', 'rights'=>array('$user->rights->agenda->allactions->create')), // Agenda
                                            array('context'=>'projectcard', 'table_element'=>'projet', 'rights'=>array('$user->rights->projet->all->creer')), // Project
                                            array('context'=>'projecttaskcard', 'table_element'=>'projet_task', 'rights'=>array('$user->rights->projet->all->creer')), // Project Task
                                            array('context'=>'contractcard', 'table_element'=>'contrat', 'rights'=>array('$user->rights->contrat->creer')), // Contract
                                            array('context'=>'interventioncard', 'table_element'=>'fichinter', 'rights'=>array('$user->rights->ficheinter->creer')), // Interventions
                                            array('context'=>'doncard', 'table_element'=>'don', 'idvar'=>'rowid', 'rights'=>array('$user->rights->don->creer')), // Dons
                                            array('context'=>'tripsandexpensescard', 'table_element'=>'deplacement', 'rights'=>array('$user->rights->deplacement->creer')), // Trips and Expenses
                                            array('context'=>'taxvatcard', 'table_element'=>'tva', 'rights'=>array('$user->rights->tax->charges->creer')), // Trips and Expenses
                                            ); // Edit me to add the support of another module - NOTE: Lowercase only!

// Triggers to attach to commit actions
$triggersarray = array('order_create'=>'commande',
                                            'order_prebuilddoc'=>'commande',
                                            'company_create'=>'societe',
                                            'contact_create'=>'socpeople',
                                            //'order_supplier_create'=>'commande_fournisseur', // special case, we don't need it for the moment because suppliers orders are immediately created (no create page), so we only need to be able to edit fields, no need for this create trigger (this may change in a future version of Dolibarr)
                                            'bill_supplier_create'=>'facture_fourn',
                                            'member_create'=>'adherent',
                                            'action_create'=>'actioncomm',
                                            'project_create'=>'projet',
                                            'task_create'=>'projet_task',
                                            'contract_create'=>'contrat',
                                            'ficheinter_create'=>'fichinter',
                                            'don_create'=>'don',
                                            'deplacement_create'=>'deplacement',
                                            ); // Edit me to add the support of actions of another module - NOTE: Lowercase only!

// Native SQL data types natively supported by CustomFields
// Edit me to add new data types to be supported in custom fields (then manage their output in forms in /htdocs/customfields/class/customfields.class.php in showOutputField() function and printField())
// sqldatatype => long_name_you_choose_to_show_to_user
$sql_datatypes = array( 'varchar' => $langs->trans("Textbox"),
                                             'text' => $langs->trans("Areabox"),
                                             'enum(\'Yes\',\'No\')' => $langs->trans("YesNoBox"),
                                             'boolean' => $langs->trans("TrueFalseBox"),
                                             'enum' => $langs->trans("DropdownBox"),
                                             'date' => $langs->trans("DateBox"),
                                             'datetime' => $langs->trans("DateTimeBox"),
                                             'int' => $langs->trans("Integer"),
                                             'float' => $langs->trans("Float"),
                                            'double' => $langs->trans("Double"),
                                             'other' => $langs->trans("Other").'/'.$langs->trans("Constraint"),
                                                );
